Sunburst plot for enriched GO term
A data frame with enriched GO terms
An OrgDb object
An igraph graph. Output of getGraph.
Column name in df which store the GO IDs
Column name in df used to set the fill colors
Column name in df used to set the area of a proportional sub-rectangle, which represent a share of the whole. The values should be a number in the range from 0 to 1. If it is a count number, it will be convert to a proportion by divided the total number of features in the term. Otherwise, will simply re-scale to .
The cutoff of the GO annotation levels
Filter the sub graphs by the edge numbers.
The GO terms must be kept.
Only keep branches with give GO terms.
Fill the NA values by 0 or not for the color column.
The ontology category of the GO IDs
plot tools, plotly or ggplot2.
parameter passed to ggSunburst.
A plot handle
library(org.Dr.eg.db)
df <- data.frame(
ID = c("GO:0007267", "GO:0099536", "GO:0099537", "GO:0098916"),
qvalue = -10 * log10(runif(4, max = 0.05))
)
sunburstGO(df, org.Dr.eg.db)